You are viewing a plain text version of this content. The canonical link for it is here.
Posted to axis-cvs@ws.apache.org by da...@apache.org on 2005/12/13 07:26:29 UTC

svn commit: r356488 [2/8] - in /webservices/axis2/trunk/c: include/ modules/core/addr/src/ modules/core/context/src/ modules/core/deployment/src/ modules/core/description/src/ modules/core/engine/src/ modules/core/phaseresolver/src/ modules/core/transp...

Modified: webservices/axis2/trunk/c/include/axis2_operation.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_operation.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_operation.h (original)
+++ webservices/axis2/trunk/c/include/axis2_operation.h Mon Dec 12 22:23:36 2005
@@ -18,13 +18,13 @@
 #define AXIS2_OPERATION_H
 
 /**
-  * @file axis2_operation.h
-  * @brief axis2 operation interface
+  * @file axis2_op.h
+  * @brief axis2 op interface
   */
 
 #include <axis2_core.h>
 #include <axis2_param_container.h>
-#include <axis2_wsdl_operation.h>
+#include <axis2_wsdl_op.h>
 #include <axis2_svc.h>
 #include <axis2_msg_recv.h>
 #include <axis2_array_list.h>
@@ -39,34 +39,34 @@
 {
 #endif
 
-/** @defgroup axis2_operation Operation Description
+/** @defgroup axis2_op Operation Description
   * @ingroup axis2_core_description
   * @{
   */
 
-struct axis2_wsdl_operation;    
+struct axis2_wsdl_op;    
 struct axis2_svc;
 struct axis2_msg_recv;
 struct axis2_param_container;
 struct axis2_module_desc; 
-struct axis2_operation;
+struct axis2_op;
 struct axis2_wsdl_feature;
 struct axis2_wsdl_property; 
 struct axis2_wsdl_fault_ref;    
-typedef struct axis2_operation_ops axis2_operation_ops_t;    
-typedef struct axis2_operation axis2_operation_t;    
+typedef struct axis2_op_ops axis2_op_ops_t;    
+typedef struct axis2_op axis2_op_t;    
     
 /** 
- * @brief Operation operations struct
- * Encapsulator struct for operations of axis2_operation
+ * @brief Operation ops struct
+ * Encapsulator struct for ops of axis2_op
  */    
-AXIS2_DECLARE_DATA struct axis2_operation_ops
+AXIS2_DECLARE_DATA struct axis2_op_ops
 {
     /** De-allocate memory
   	 * @return status code
   	 */
 	axis2_status_t (AXIS2_CALL *
-    free) (axis2_operation_t *operation, 
+    free) (axis2_op_t *op, 
            axis2_env_t **env);
 
     /**
@@ -75,7 +75,7 @@
      * @param param Parameter that will be added
      */
 	axis2_status_t (AXIS2_CALL *
-    add_param)(axis2_operation_t *operation, 
+    add_param)(axis2_op_t *op, 
                 axis2_env_t **env, 
                 axis2_param_t *param);
     
@@ -85,65 +85,65 @@
      * @param name Name of the parameter
      */
 	axis2_param_t *(AXIS2_CALL *
-    get_param)(axis2_operation_t *operation, 
+    get_param)(axis2_op_t *op, 
                 axis2_env_t **env,
                 axis2_char_t *name);
 
 
 	axis2_array_list_t *(AXIS2_CALL *
-    get_params) (axis2_operation_t *operation, 
+    get_params) (axis2_op_t *op, 
                     axis2_env_t **env);
 
     /**
      * To check whether a given paramter is locked
      */
 	axis2_bool_t (AXIS2_CALL *
-    is_param_locked) (axis2_operation_t *operation, 
+    is_param_locked) (axis2_op_t *op, 
                         axis2_env_t **env,
                         axis2_char_t *param_name);
 	
 	axis2_status_t (AXIS2_CALL *
-    set_parent) (axis2_operation_t *operation, 
+    set_parent) (axis2_op_t *op, 
                                      axis2_env_t **env,
                                      struct axis2_svc *service_desc);
 
 	struct axis2_svc *(AXIS2_CALL *
-    get_parent) (axis2_operation_t *operation, 
+    get_parent) (axis2_op_t *op, 
                  axis2_env_t **env);
 
     axis2_status_t (AXIS2_CALL *
-    set_name) (axis2_operation_t *operation, 
+    set_name) (axis2_op_t *op, 
                 axis2_env_t **env,
                 axis2_qname_t *qname);
     
 	axis2_qname_t *(AXIS2_CALL *
-    get_name) (axis2_operation_t *operation, 
+    get_name) (axis2_op_t *op, 
                 axis2_env_t **env);
 
 	axis2_status_t (AXIS2_CALL *
-    set_msg_exchange_pattern) (axis2_operation_t *operation, 
+    set_msg_exchange_pattern) (axis2_op_t *op, 
                                 axis2_env_t **env,
                                 const axis2_char_t *pattern);
 
 	axis2_char_t *(AXIS2_CALL *
-    get_msg_exchange_pattern) (axis2_operation_t *operation, 
+    get_msg_exchange_pattern) (axis2_op_t *op, 
                                 axis2_env_t **env);
 
 	axis2_status_t (AXIS2_CALL *
-    set_msg_recv) (axis2_operation_t *operation, 
+    set_msg_recv) (axis2_op_t *op, 
                     axis2_env_t **env,
                     struct axis2_msg_recv *msg_recv);
 
 	struct axis2_msg_recv *(AXIS2_CALL *
-        get_msg_recv) (axis2_operation_t *operation, 
+        get_msg_recv) (axis2_op_t *op, 
                        axis2_env_t **env);
                                         
     axis2_char_t *(AXIS2_CALL *
-    get_style) (axis2_operation_t *operation,
+    get_style) (axis2_op_t *op,
                 axis2_env_t **env);
 
     axis2_status_t  (AXIS2_CALL *
-    set_style) (axis2_operation_t *operation,
+    set_style) (axis2_op_t *op,
                 axis2_env_t **env,
                 axis2_char_t *style);
                                                 
@@ -154,12 +154,12 @@
      * @throws org.apache.axis2.AxisFault
      */
     axis2_status_t (AXIS2_CALL *
-    engage_module) (axis2_operation_t *operation,
+    engage_module) (axis2_op_t *op,
                         axis2_env_t **env,
                         struct axis2_module_desc *moduleref);
     
     axis2_status_t (AXIS2_CALL *
-    add_to_engage_module_list) (axis2_operation_t *operation,
+    add_to_engage_module_list) (axis2_op_t *op,
                                 axis2_env_t **env,
                                 struct axis2_module_desc *module_name);
     
@@ -168,7 +168,7 @@
      *
      */
     axis2_array_list_t *(AXIS2_CALL *
-    get_modules) (axis2_operation_t *operation,
+    get_modules) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     /**
@@ -178,33 +178,33 @@
      *
      */
     int (AXIS2_CALL *
-    get_axis_specific_MEP_constant) (axis2_operation_t *operation,
+    get_axis_specific_MEP_constant) (axis2_op_t *op,
                                                     axis2_env_t **env);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_phases_in_fault_flow) (axis2_operation_t *operation,
+    get_phases_in_fault_flow) (axis2_op_t *op,
                                                 axis2_env_t **env);
     
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_phases_out_fault_flow) (axis2_operation_t *operation,
+    get_phases_out_fault_flow) (axis2_op_t *op,
                                                 axis2_env_t **env);
     
     
     axis2_array_list_t * (AXIS2_CALL *
-    get_phases_outflow) (axis2_operation_t *operation,
+    get_phases_outflow) (axis2_op_t *op,
                                             axis2_env_t **env);
     
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_remaining_phases_inflow) (axis2_operation_t *operation,
+    get_remaining_phases_inflow) (axis2_op_t *op,
                                                     axis2_env_t **env);
     
     /**
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_phases_in_fault_flow) (axis2_operation_t *operation,
+    set_phases_in_fault_flow) (axis2_op_t *op,
                                                 axis2_env_t **env,
                                                 axis2_array_list_t *list);
     
@@ -212,7 +212,7 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_phases_out_fault_flow) (axis2_operation_t *operation,
+    set_phases_out_fault_flow) (axis2_op_t *op,
                                                 axis2_env_t **env,
                                                 axis2_array_list_t *list);
     
@@ -220,7 +220,7 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_phases_outflow) (axis2_operation_t *operation,
+    set_phases_outflow) (axis2_op_t *op,
                                             axis2_env_t **env,
                                             axis2_array_list_t *list);
     
@@ -228,282 +228,282 @@
      * @param list
      */
     axis2_status_t (AXIS2_CALL *
-    set_remaining_phases_inflow) (axis2_operation_t *operation,
+    set_remaining_phases_inflow) (axis2_op_t *op,
                                                     axis2_env_t **env,
                                                     axis2_array_list_t *list);
                                                     
     axis2_status_t (AXIS2_CALL *
-    add_module) (axis2_operation_t *operation,
+    add_module) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     axis2_qname_t *module_name);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_module_refs) (axis2_operation_t *operation,
+    get_module_refs) (axis2_op_t *op,
                                         axis2_env_t **env);
     
     axis2_linked_list_t *(AXIS2_CALL *
-    get_infaults) (axis2_operation_t *operation,
+    get_infaults) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_infaults) (axis2_operation_t *operation,
+    set_infaults) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     axis2_linked_list_t *infaults);
     
     struct axis2_wsdl_msg_ref *(AXIS2_CALL *
-    get_input_msg) (axis2_operation_t *operation,
+    get_input_msg) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_input_msg) (axis2_operation_t *operation,
+    set_input_msg) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_msg_ref *input_msg);
     
     axis2_linked_list_t *(AXIS2_CALL *
-    get_outfaults) (axis2_operation_t *operation,
+    get_outfaults) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_outfaults) (axis2_operation_t *operation,
+    set_outfaults) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     axis2_linked_list_t *outfaults);
     
     struct axis2_wsdl_msg_ref *(AXIS2_CALL *
-    get_output_msg) (axis2_operation_t *operation,
+    get_output_msg) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_output_msg) (axis2_operation_t *operation,
+    set_output_msg) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_msg_ref *output_msg);
     
     axis2_bool_t (AXIS2_CALL *
-    is_safe) (axis2_operation_t *operation,
+    is_safe) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_safety) (axis2_operation_t *operation,
+    set_safety) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     axis2_bool_t safe);
                                     
     axis2_char_t *(AXIS2_CALL *
-    get_target_namespace) (axis2_operation_t *operation,
+    get_target_namespace) (axis2_op_t *op,
                                             axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    add_infault) (axis2_operation_t *operation,
+    add_infault) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_fault_ref *infault);
     
     axis2_status_t (AXIS2_CALL *
-    add_outfault) (axis2_operation_t *operation,
+    add_outfault) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_fault_ref *outfault);
     
     axis2_status_t (AXIS2_CALL *
-    add_feature) (axis2_operation_t *operation,
+    add_feature) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_feature *feature);
     
     axis2_linked_list_t *(AXIS2_CALL *
-    get_features) (axis2_operation_t *operation,
+    get_features) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    add_property) (axis2_operation_t *operation,
+    add_property) (axis2_op_t *op,
                                     axis2_env_t **env,
                                     struct axis2_wsdl_property *wsdl_property);
     
     axis2_linked_list_t *(AXIS2_CALL *
-    get_Properties) (axis2_operation_t *operation,
+    get_Properties) (axis2_op_t *op,
                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL * 
-    set_wsdl_opeartion) (axis2_operation_t *operation,
+    set_wsdl_opeartion) (axis2_op_t *op,
                                     axis2_env_t **env,
-                                    struct axis2_wsdl_operation *wsdl_operation);                                           
+                                    struct axis2_wsdl_op *wsdl_op);                                           
 };
 
 /** 
  * @brief Operaton struct
  *	Axis2 Operation   
  */  
-AXIS2_DECLARE_DATA struct axis2_operation
+AXIS2_DECLARE_DATA struct axis2_op
 {
-	axis2_operation_ops_t *ops;
-    struct axis2_wsdl_operation *wsdl_operation;
+	axis2_op_ops_t *ops;
+    struct axis2_wsdl_op *wsdl_op;
     struct axis2_param_container *param_container;
 };
 
 /** 
- * Creates operation struct
- * @return pointer to newly created operation
+ * Creates op struct
+ * @return pointer to newly created op
  */
-AXIS2_DECLARE(axis2_operation_t *)
-axis2_operation_create (axis2_env_t **env);
+AXIS2_DECLARE(axis2_op_t *)
+axis2_op_create (axis2_env_t **env);
 
 /** 
- * Creates operation struct with name
- * @param name operation name
- * @return pointer to newly created operation
+ * Creates op struct with name
+ * @param name op name
+ * @return pointer to newly created op
  */
-AXIS2_DECLARE(axis2_operation_t *)
-axis2_operation_create_with_name (axis2_env_t **env, 
+AXIS2_DECLARE(axis2_op_t *)
+axis2_op_create_with_name (axis2_env_t **env, 
                                                 axis2_qname_t *name);
 
 /** 
- * Creates operation struct with wsdl operation
- * @param wsdl_operation wsdl operation
- * @return pointer to newly created operation
+ * Creates op struct with wsdl op
+ * @param wsdl_op wsdl op
+ * @return pointer to newly created op
  */
-AXIS2_DECLARE(axis2_operation_t *) 
-axis2_operation_create_with_wsdl_operation (axis2_env_t **env, 
-                                            struct axis2_wsdl_operation *wsdl_operation);
+AXIS2_DECLARE(axis2_op_t *) 
+axis2_op_create_with_wsdl_op (axis2_env_t **env, 
+                                            struct axis2_wsdl_op *wsdl_op);
 
 /************************** Start of function macros **************************/
 
-#define AXIS2_OPERATION_FREE(operation, env) \
-        ((operation->ops)->free (operation, env))
+#define AXIS2_OPERATION_FREE(op, env) \
+        ((op->ops)->free (op, env))
 
-#define AXIS2_OPERATION_ADD_PARAM(operation, env, param) \
-		((operation->ops)->add_param (operation, env, param))
+#define AXIS2_OPERATION_ADD_PARAM(op, env, param) \
+		((op->ops)->add_param (op, env, param))
 
-#define AXIS2_OPERATION_GET_PARAM(operation, env) \
-		((operation->ops)->get_param (operation, env))
+#define AXIS2_OPERATION_GET_PARAM(op, env) \
+		((op->ops)->get_param (op, env))
 
-#define AXIS2_OPERATION_GET_PARAMS(operation, env) \
-		((operation->ops)->get_params (operation, env))
+#define AXIS2_OPERATION_GET_PARAMS(op, env) \
+		((op->ops)->get_params (op, env))
 
-#define AXIS2_OPERATION_IS_PARAM_LOCKED(operation, env, param_name) \
-        ((operation->ops)->is_param_locked(operation, env, param_name))
+#define AXIS2_OPERATION_IS_PARAM_LOCKED(op, env, param_name) \
+        ((op->ops)->is_param_locked(op, env, param_name))
 
-#define AXIS2_OPERATION_SET_PARENT(operation, env, service_desc) \
-        ((operation->ops)->set_parent (operation, env, service_desc))
+#define AXIS2_OPERATION_SET_PARENT(op, env, service_desc) \
+        ((op->ops)->set_parent (op, env, service_desc))
 
-#define AXIS2_OPERATION_GET_PARENT(operation, env) \
-		((operation->ops)->get_parent (operation, env))
+#define AXIS2_OPERATION_GET_PARENT(op, env) \
+		((op->ops)->get_parent (op, env))
 
-#define AXIS2_OPERATION_SET_MSG_RECEIVER(operation, env, msg_recv) \
-        ((operation->ops)->set_msg_recv (operation, env, msg_recv))
+#define AXIS2_OPERATION_SET_MSG_RECEIVER(op, env, msg_recv) \
+        ((op->ops)->set_msg_recv (op, env, msg_recv))
 
-#define AXIS2_OPERATION_GET_MSG_RECEIVER(operation, env) \
-		((operation->ops)->get_msg_recv (operation, env))
+#define AXIS2_OPERATION_GET_MSG_RECEIVER(op, env) \
+		((op->ops)->get_msg_recv (op, env))
 
-#define AXIS2_OPERATION_SET_NAME(operation, env, qname) \
-		((operation->ops)->set_name (operation, env, qname))
+#define AXIS2_OPERATION_SET_NAME(op, env, qname) \
+		((op->ops)->set_name (op, env, qname))
         
-#define AXIS2_OPERATION_GET_NAME(operation, env) \
-		((operation->ops)->get_name (operation, env))
+#define AXIS2_OPERATION_GET_NAME(op, env) \
+		((op->ops)->get_name (op, env))
 
-#define AXIS2_OPERATION_SET_MSG_EXCHANGE_PATTERN(operation , env, \
+#define AXIS2_OPERATION_SET_MSG_EXCHANGE_PATTERN(op , env, \
         msg_exchange_pattern) \
-		((operation->ops)->set_msg_exchange_pattern (operation, env, \
+		((op->ops)->set_msg_exchange_pattern (op, env, \
         msg_exchange_pattern))
 
-#define AXIS2_OPERATION_GET_MSG_EXCHANGE_PATTERN(operation, env) \
-		((operation->ops)->get_msg_exchange_pattern (operation, env))
+#define AXIS2_OPERATION_GET_MSG_EXCHANGE_PATTERN(op, env) \
+		((op->ops)->get_msg_exchange_pattern (op, env))
         
-#define AXIS2_OPERATION_GET_STYLE(operation, env) \
-		((operation->ops)->get_style (operation, env))
+#define AXIS2_OPERATION_GET_STYLE(op, env) \
+		((op->ops)->get_style (op, env))
         
-#define AXIS2_OPERATION_SET_STYLE(operation, env, style) \
-		((operation->ops)->set_style (operation, env, style))   
+#define AXIS2_OPERATION_SET_STYLE(op, env, style) \
+		((op->ops)->set_style (op, env, style))   
 
-#define AXIS2_OPERATION_ENGAGE_MODULE(operation, env, moduleref) \
-		((operation->ops)->engage_module (operation, env, moduleref))
+#define AXIS2_OPERATION_ENGAGE_MODULE(op, env, moduleref) \
+		((op->ops)->engage_module (op, env, moduleref))
         
-#define AXIS2_OPERATION_ADD_TO_ENGAGE_MODULE_LIST(operation, env, module_name) \
-		((operation->ops)->add_to_engage_module_list (operation, env, module_name))
+#define AXIS2_OPERATION_ADD_TO_ENGAGE_MODULE_LIST(op, env, module_name) \
+		((op->ops)->add_to_engage_module_list (op, env, module_name))
 
-#define AXIS2_OPERATION_GET_MODULES(operation, env) \
-		((operation->ops)->get_modules (operation, env))
+#define AXIS2_OPERATION_GET_MODULES(op, env) \
+		((op->ops)->get_modules (op, env))
         
-#define AXIS2_OPERATION_GET_AXIS_SPECIFIC_MEP_CONSTANT(operation, env) \
-		((operation->ops)->get_axis_specific_MEP_constant (operation, env))
+#define AXIS2_OPERATION_GET_AXIS_SPECIFIC_MEP_CONSTANT(op, env) \
+		((op->ops)->get_axis_specific_MEP_constant (op, env))
 
-#define AXIS2_OPERATION_GET_PHASES_IN_FAULT_FLOW(operation, env) \
-		((operation->ops)->get_phases_in_fault_flow (operation, env))
+#define AXIS2_OPERATION_GET_PHASES_IN_FAULT_FLOW(op, env) \
+		((op->ops)->get_phases_in_fault_flow (op, env))
         
-#define AXIS2_OPERATION_GET_PHASES_OUT_FAULT_FLOW(operation, env) \
-		((operation->ops)->get_phases_out_fault_flow (operation, env))
+#define AXIS2_OPERATION_GET_PHASES_OUT_FAULT_FLOW(op, env) \
+		((op->ops)->get_phases_out_fault_flow (op, env))
 
-#define AXIS2_OPERATION_GET_PHASES_OUTFLOW(operation, env) \
-		((operation->ops)->get_phases_outflow (operation, env))
+#define AXIS2_OPERATION_GET_PHASES_OUTFLOW(op, env) \
+		((op->ops)->get_phases_outflow (op, env))
  
-#define AXIS2_OPERATION_GET_REMAINING_PHASES_INFLOW(operation, env) \
-		((operation->ops)->get_remaining_phases_inflow (operation, env))    
+#define AXIS2_OPERATION_GET_REMAINING_PHASES_INFLOW(op, env) \
+		((op->ops)->get_remaining_phases_inflow (op, env))    
 
-#define AXIS2_OPERATION_SET_PHASES_IN_FAULT_FLOW(operation, env, list) \
-		((operation->ops)->set_phases_in_fault_flow (operation, env, list))    
+#define AXIS2_OPERATION_SET_PHASES_IN_FAULT_FLOW(op, env, list) \
+		((op->ops)->set_phases_in_fault_flow (op, env, list))    
 
-#define AXIS2_OPERATION_SET_PHASES_OUT_FAULT_FLOW(operation, env, list) \
-		((operation->ops)->set_phases_out_fault_flow (operation, env, list))   
+#define AXIS2_OPERATION_SET_PHASES_OUT_FAULT_FLOW(op, env, list) \
+		((op->ops)->set_phases_out_fault_flow (op, env, list))   
 
-#define AXIS2_OPERATION_SET_PHASES_OUTFLOW(operation, env, list) \
-		((operation->ops)->set_phases_outflow (operation, env, list)) 
+#define AXIS2_OPERATION_SET_PHASES_OUTFLOW(op, env, list) \
+		((op->ops)->set_phases_outflow (op, env, list)) 
         
-#define AXIS2_OPERATION_SET_REMAINING_PHASES_INFLOW(operation, env, list) \
-		((operation->ops)->set_remaining_phases_inflow (operation, env, list))
+#define AXIS2_OPERATION_SET_REMAINING_PHASES_INFLOW(op, env, list) \
+		((op->ops)->set_remaining_phases_inflow (op, env, list))
         
-#define AXIS2_OPERATION_ADD_MODULE(operation, env, module_name) \
-		((operation->ops)->add_module (operation, env, module_name))
+#define AXIS2_OPERATION_ADD_MODULE(op, env, module_name) \
+		((op->ops)->add_module (op, env, module_name))
 
-#define AXIS2_OPERATION_GET_MODULE_REFS(operation, env) \
-		((operation->ops)->get_module_refs (operation, env))
+#define AXIS2_OPERATION_GET_MODULE_REFS(op, env) \
+		((op->ops)->get_module_refs (op, env))
         
-#define AXIS2_OPERATION_GET_INFAULTS(operation, env) \
-		((operation->ops)->get_infaults (operation, env))
+#define AXIS2_OPERATION_GET_INFAULTS(op, env) \
+		((op->ops)->get_infaults (op, env))
 
-#define AXIS2_OPERATION_SET_INFAULTS(operation, env) \
-		((operation->ops)->set_infaults (operation, env, infaults))
+#define AXIS2_OPERATION_SET_INFAULTS(op, env) \
+		((op->ops)->set_infaults (op, env, infaults))
         
-#define AXIS2_OPERATION_GET_INPUT_MSG(operation, env) \
-		((operation->ops)->get_input_msg (operation, env))
+#define AXIS2_OPERATION_GET_INPUT_MSG(op, env) \
+		((op->ops)->get_input_msg (op, env))
 
-#define AXIS2_OPERATION_SET_INPUT_MSG(operation, env) \
-		((operation->ops)->set_input_msg (operation, env, input_msg))
+#define AXIS2_OPERATION_SET_INPUT_MSG(op, env) \
+		((op->ops)->set_input_msg (op, env, input_msg))
         
-#define AXIS2_OPERATION_GET_OUTFAULTS(operation, env) \
-		((operation->ops)->get_outfaults (operation, env))
+#define AXIS2_OPERATION_GET_OUTFAULTS(op, env) \
+		((op->ops)->get_outfaults (op, env))
 
-#define AXIS2_OPERATION_SET_OUTFAULTS(operation, env) \
-		((operation->ops)->set_outfaults (operation, env, outfaults))
+#define AXIS2_OPERATION_SET_OUTFAULTS(op, env) \
+		((op->ops)->set_outfaults (op, env, outfaults))
         
-#define AXIS2_OPERATION_GET_OUTPUT_MSG(operation, env) \
-		((operation->ops)->get_output_msg (operation, env))
+#define AXIS2_OPERATION_GET_OUTPUT_MSG(op, env) \
+		((op->ops)->get_output_msg (op, env))
 
-#define AXIS2_OPERATION_SET_OUTPUT_MSG(operation, env) \
-		((operation->ops)->set_output_msg (operation, env, output_msg))
+#define AXIS2_OPERATION_SET_OUTPUT_MSG(op, env) \
+		((op->ops)->set_output_msg (op, env, output_msg))
         
-#define AXIS2_OPERATION_IS_SAFE(operation, env) \
-		((operation->ops)->is_safe (operation, env))
+#define AXIS2_OPERATION_IS_SAFE(op, env) \
+		((op->ops)->is_safe (op, env))
 
-#define AXIS2_OPERATION_SET_SAFETY(operation, env, safe) \
-		((operation->ops)->set_safety (operation, env, safe))
+#define AXIS2_OPERATION_SET_SAFETY(op, env, safe) \
+		((op->ops)->set_safety (op, env, safe))
         
-#define AXIS2_OPERATION_GET_TARGET_NAMESPACE(operation, env) \
-		((operation->ops)->get_target_namespace (operation, env))
+#define AXIS2_OPERATION_GET_TARGET_NAMESPACE(op, env) \
+		((op->ops)->get_target_namespace (op, env))
 
-#define AXIS2_OPERATION_ADD_INFAULT(operation, env, infault) \
-		((operation->ops)->add_infault (operation, env, infault))
+#define AXIS2_OPERATION_ADD_INFAULT(op, env, infault) \
+		((op->ops)->add_infault (op, env, infault))
         
-#define AXIS2_OPERATION_ADD_OUTFAULT(operation, env, outfault) \
-		((operation->ops)->add_outfault (operation, env, outfault))
+#define AXIS2_OPERATION_ADD_OUTFAULT(op, env, outfault) \
+		((op->ops)->add_outfault (op, env, outfault))
 
-#define AXIS2_OPERATION_ADD_FEATURE(operation, env, feature) \
-		((operation->ops)->add_feature (operation, env, feature))
+#define AXIS2_OPERATION_ADD_FEATURE(op, env, feature) \
+		((op->ops)->add_feature (op, env, feature))
         
-#define AXIS2_OPERATION_GET_FEATURES(operation, env) \
-		((operation->ops)->get_features(operation, env))
+#define AXIS2_OPERATION_GET_FEATURES(op, env) \
+		((op->ops)->get_features(op, env))
 
-#define AXIS2_OPERATION_ADD_PROPERTY(operation, env, wsdl_property) \
-		((operation->ops)->add_property (operation, env, wsdl_property))
+#define AXIS2_OPERATION_ADD_PROPERTY(op, env, wsdl_property) \
+		((op->ops)->add_property (op, env, wsdl_property))
         
-#define AXIS2_OPERATION_GET_PROPERTIES(operation, env) \
-		((operation->ops)->get_properties (operation, env, properties))
+#define AXIS2_OPERATION_GET_PROPERTIES(op, env) \
+		((op->ops)->get_properties (op, env, properties))
 
-#define AXIS2_OPERATION_SET_WSDL_OPERATION(operation, env) \
-		((operation->ops)->set_wsdl_opeartion (operation, env))
+#define AXIS2_OPERATION_SET_WSDL_OPERATION(op, env) \
+		((op->ops)->set_wsdl_opeartion (op, env))
 
 /************************** End of function macros ****************************/
 

Modified: webservices/axis2/trunk/c/include/axis2_operation_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_operation_ctx.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_param.h (original)
+++ webservices/axis2/trunk/c/include/axis2_param.h Mon Dec 12 22:23:36 2005
@@ -52,7 +52,7 @@
   static const int AXIS2_DOM_PARAM = 1;
        
 /**
- *   \brief param operations struct
+ *   \brief param ops struct
  */
 AXIS2_DECLARE_DATA typedef struct axis2_param_ops
     {
@@ -148,7 +148,7 @@
  */
 typedef struct axis2_param
 {
-	/** Parameter related operations */
+	/** Parameter related ops */
 	axis2_param_ops_t *ops;
 }axis2_param_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_param_container.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_param_container.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_param_container.h (original)
+++ webservices/axis2/trunk/c/include/axis2_param_container.h Mon Dec 12 22:23:36 2005
@@ -49,8 +49,8 @@
  */
 
 /** 
- * @brief Param Container operations struct
- * Encapsulator struct for operations of axis2_param_container
+ * @brief Param Container ops struct
+ * Encapsulator struct for ops of axis2_param_container
  */
 AXIS2_DECLARE_DATA typedef struct axis2_param_container_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_phase.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase.h Mon Dec 12 22:23:36 2005
@@ -53,7 +53,7 @@
  */
 
 /**
- *   \brief Phase operations struct
+ *   \brief Phase ops struct
  */
  AXIS2_DECLARE_DATA   typedef struct axis2_phase_ops
     {
@@ -159,7 +159,7 @@
     */
     typedef struct axis2_phase
     {
-        /** Phase related operations */
+        /** Phase related ops */
         axis2_phase_ops_t *ops;
     } axis2_phase_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_phase_holder.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase_holder.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase_holder.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase_holder.h Mon Dec 12 22:23:36 2005
@@ -19,7 +19,7 @@
 
 /**
  * @file axis2_phase_holder.h
- * @brief Axis2 Wsdl soap operation interface
+ * @brief Axis2 Wsdl soap op interface
  */
 
 #include <axis2.h>
@@ -53,8 +53,8 @@
  */
 
 /** 
- * @brief Wsdl Phase Holder operations struct
- * Encapsulator struct for operations of axis2_phase_holder
+ * @brief Wsdl Phase Holder ops struct
+ * Encapsulator struct for ops of axis2_phase_holder
  */
 AXIS2_DECLARE_DATA struct axis2_phase_holder_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_phase_resolver.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase_resolver.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase_resolver.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase_resolver.h Mon Dec 12 22:23:36 2005
@@ -19,7 +19,7 @@
 
 /**
  * @file axis2_phase_resolver.h
- * @brief Axis2 Wsdl soap operation interface
+ * @brief Axis2 Wsdl soap op interface
  */
 
 #include <axis2.h>
@@ -52,7 +52,7 @@
 struct axis2_phase_rule;
 struct axis2_svc;
 struct axis2_engine_config;
-struct axis2_operation; 
+struct axis2_op; 
 struct axis2_phase_holder;    
 typedef struct axis2_phase_resolver axis2_phase_resolver_t;
 typedef struct axis2_phase_resolver_ops axis2_phase_resolver_ops_t;
@@ -63,8 +63,8 @@
  */
 
 /** 
- * @brief Wsdl Phase Resolver operations struct
- * Encapsulator struct for operations of axis2_phase_resolver
+ * @brief Wsdl Phase Resolver ops struct
+ * Encapsulator struct for ops of axis2_phase_resolver
  */
 AXIS2_DECLARE_DATA struct axis2_phase_resolver_ops
 {
@@ -88,13 +88,13 @@
     /**
      * To build the opration for the opeartion which the module going to be added
      *
-     * @param operation <code>AxisOperation</code>
+     * @param op <code>AxisOperation</code>
      * @throws AxisFault
      */
     axis2_status_t (AXIS2_CALL *
-    build_module_operation) (axis2_phase_resolver_t *phase_resolver,
+    build_module_op) (axis2_phase_resolver_t *phase_resolver,
                                 axis2_env_t **env,
-                                struct axis2_operation *operation);
+                                struct axis2_op *op);
     
     
     
@@ -134,9 +134,9 @@
                             struct axis2_module_desc *module_desc);
                                                         
     axis2_status_t (AXIS2_CALL *
-    engage_module_to_operation) (axis2_phase_resolver_t *phase_resolver,
+    engage_module_to_op) (axis2_phase_resolver_t *phase_resolver,
                                     axis2_env_t **env,
-                                    struct axis2_operation *axis_operation,
+                                    struct axis2_op *axis_op,
                                     struct axis2_module_desc *module_desc);    
 
 
@@ -185,8 +185,8 @@
 #define AXIS2_PHASE_RESOLVER_BUILD_CHAINS(phase_resolver, env) \
 		((phase_resolver->ops)->build_chains (phase_resolver, env))
 
-#define AXIS2_PHASE_RESOLVER_BUILD_MODULE_OPERATION(phase_resolver, env, operation) \
-		((phase_resolver->ops)->build_module_operation (phase_resolver, env, operation))
+#define AXIS2_PHASE_RESOLVER_BUILD_MODULE_OPERATION(phase_resolver, env, op) \
+		((phase_resolver->ops)->build_module_op (phase_resolver, env, op))
 
 #define AXIS2_PHASE_RESOLVER_BUILD_TRANSPORT_CHAINS(phase_resolver, env) \
 		((phase_resolver->ops)->build_transport_chains (phase_resolver, env))
@@ -200,8 +200,8 @@
 #define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_SVC(phase_resolver, env, svc, module_desc) \
 		((phase_resolver->ops)->engage_module_to_svc (phase_resolver, env, svc, module_desc))
 
-#define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OPERATION(phase_resolver, env, axis_operation, module_desc) \
-		((phase_resolver->ops)->engage_module_to_operation (phase_resolver, env, axis_operation, module_desc))
+#define AXIS2_PHASE_RESOLVER_ENGAGE_MODULE_TO_OPERATION(phase_resolver, env, axis_op, module_desc) \
+		((phase_resolver->ops)->engage_module_to_op (phase_resolver, env, axis_op, module_desc))
 
         
 /*************************** End of function macros ***************************/

Modified: webservices/axis2/trunk/c/include/axis2_phase_rule.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phase_rule.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phase_rule.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phase_rule.h Mon Dec 12 22:23:36 2005
@@ -41,7 +41,7 @@
  */
 
 /**
- *   \brief Phase Rule operations struct
+ *   \brief Phase Rule ops struct
  */
  AXIS2_DECLARE_DATA   typedef struct axis2_phase_rule_ops
     {        
@@ -77,7 +77,7 @@
     */
     typedef struct axis2_phase_rule
     {
-        /** Phase Rule related operations */
+        /** Phase Rule related ops */
         axis2_phase_rule_ops_t *ops;
     } axis2_phase_rule_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_phases_info.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_phases_info.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_phases_info.h (original)
+++ webservices/axis2/trunk/c/include/axis2_phases_info.h Mon Dec 12 22:23:36 2005
@@ -12,7 +12,7 @@
 #include <axis2_allocator.h>
 #include <axis2_string.h>
 #include <axis2_array_list.h>
-#include <axis2_operation.h>
+#include <axis2_op.h>
 #include <axis2_phase.h>
 
 #ifdef __cplusplus
@@ -30,8 +30,8 @@
   */
 
 /** 
- * @brief Phases Info operations struct
- * Encapsulator struct for operations of axis2_phases_info
+ * @brief Phases Info ops struct
+ * Encapsulator struct for ops of axis2_phases_info
  */
 struct axis2_phases_info_ops
 {
@@ -78,25 +78,25 @@
                                             axis2_env_t **env);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_operation_inphases) (axis2_phases_info_t *phases_info,
+    get_op_inphases) (axis2_phases_info_t *phases_info,
                                             axis2_env_t **env);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_operation_outphases) (axis2_phases_info_t *phases_info,
+    get_op_outphases) (axis2_phases_info_t *phases_info,
                                                 axis2_env_t **env);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_operation_in_faultphases) (axis2_phases_info_t *phases_info,
+    get_op_in_faultphases) (axis2_phases_info_t *phases_info,
                                                     axis2_env_t **env);
     
     axis2_array_list_t *(AXIS2_CALL *
-    get_operation_out_faultphases) (axis2_phases_info_t *phases_info,
+    get_op_out_faultphases) (axis2_phases_info_t *phases_info,
                                                     axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_operation_phases) (axis2_phases_info_t *phases_info,
+    set_op_phases) (axis2_phases_info_t *phases_info,
                                             axis2_env_t **env,
-                                            struct axis2_operation *axis2_opt);
+                                            struct axis2_op *axis2_opt);
     
                                                 
 };
@@ -146,19 +146,19 @@
 		((phases_info->ops)->get_out_faultphases(phases_info, env)) 
         
 #define AXIS2_PHASES_INFO_GET_OPERATION_INPHASES(phases_info, env) \
-		((phases_info->ops)->get_operation_inphases(phases_info, env)) 
+		((phases_info->ops)->get_op_inphases(phases_info, env)) 
 
 #define AXIS2_PHASES_INFO_GET_OPERATION_OUTPHASES(phases_info, env) \
-		((phases_info->ops)->get_operation_outphases(phases_info, env)) 
+		((phases_info->ops)->get_op_outphases(phases_info, env)) 
                                         
 #define AXIS2_PHASES_INFO_GET_OPERATION_IN_FAULTPHASES(phases_info, env) \
-		((phases_info->ops)->get_operation_in_faultphases(phases_info, env))                                         
+		((phases_info->ops)->get_op_in_faultphases(phases_info, env))                                         
                                         
 #define AXIS2_PHASES_INFO_GET_OPERATION_OUT_FAULTPHASES(phases_info, env) \
-		((phases_info->ops)->get_operation_out_faultphases(phases_info, env))                                         
+		((phases_info->ops)->get_op_out_faultphases(phases_info, env))                                         
                                         
 #define AXIS2_PHASES_INFO_SET_OPERATION_PHASES(phases_info, env, axis2_opt) \
-		((phases_info->ops)->set_operation_phases(phases_info, env, axis2_opt))                                         
+		((phases_info->ops)->set_op_phases(phases_info, env, axis2_opt))                                         
                                            
 /**************************** End of function macros **************************/
 

Modified: webservices/axis2/trunk/c/include/axis2_qname.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_qname.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_qname.h (original)
+++ webservices/axis2/trunk/c/include/axis2_qname.h Mon Dec 12 22:23:36 2005
@@ -40,9 +40,9 @@
  */
 
 /**
- * \brief Axis2 qname operations struct
+ * \brief Axis2 qname ops struct
  *
- * Encapsulator struct for operations of axis2_qname
+ * Encapsulator struct for ops of axis2_qname
  */
                       
 AXIS2_DECLARE_DATA typedef struct axis2_qname_ops
@@ -100,7 +100,7 @@
 
 typedef struct axis2_qname
 {
-    /** operations related to qname */
+    /** ops related to qname */
     axis2_qname_ops_t *ops;
 } axis2_qname_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_relates_to.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_relates_to.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_relates_to.h (original)
+++ webservices/axis2/trunk/c/include/axis2_relates_to.h Mon Dec 12 22:23:36 2005
@@ -41,7 +41,7 @@
  */
 
 /**
- *   \brief Dispatcher operations struct
+ *   \brief Dispatcher ops struct
  */
  AXIS2_DECLARE_DATA typedef struct axis2_relates_to_ops
     { 
@@ -89,7 +89,7 @@
     */
     typedef struct axis2_relates_to
     {
-        /** Dispatcher related operations */
+        /** Dispatcher related ops */
         axis2_relates_to_ops_t *ops;
     } axis2_relates_to_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_simple_http_svr_conn.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_simple_http_svr_conn.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_simple_http_svr_conn.h (original)
+++ webservices/axis2/trunk/c/include/axis2_simple_http_svr_conn.h Mon Dec 12 22:23:36 2005
@@ -44,7 +44,7 @@
  */
 
 /**
- *   \brief Simple HTTP Server Connection operations struct
+ *   \brief Simple HTTP Server Connection ops struct
  */
 AXIS2_DECLARE_DATA struct axis2_simple_http_svr_conn_ops
 {        
@@ -95,7 +95,7 @@
 */
 AXIS2_DECLARE_DATA struct axis2_simple_http_svr_conn
 {
-    /** Simple HTTP Server Connection related operations */
+    /** Simple HTTP Server Connection related ops */
     axis2_simple_http_svr_conn_ops_t *ops;
 };
 

Modified: webservices/axis2/trunk/c/include/axis2_stream.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_stream.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_stream.h (original)
+++ webservices/axis2/trunk/c/include/axis2_stream.h Mon Dec 12 22:23:36 2005
@@ -34,9 +34,9 @@
  */
 
   /** 
-    * \brief Axis2 stream operations struct
+    * \brief Axis2 stream ops struct
     *
-    * Encapsulator struct for operations of axis2_stream
+    * Encapsulator struct for ops of axis2_stream
     */
   AXIS2_DECLARE_DATA  typedef struct axis2_stream_ops
     {
@@ -52,7 +52,7 @@
         * reads from stream
         * @param buffer buffer into which the content is to be read
         * @param size size of the buffer
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
+        * @return satus of the op. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *read) (void *buffer
 			, size_t count);
@@ -60,7 +60,7 @@
         * writes into stream
         * @param buffer buffer to be written
         * @param size size of the buffer
-        * @return satus of the operation. AXIS2_SUCCESS on success else AXIS2_FAILURE
+        * @return satus of the op. AXIS2_SUCCESS on success else AXIS2_FAILURE
         */
         axis2_status_t (AXIS2_CALL *write) 
 			(const void *buffer, size_t count);
@@ -103,11 +103,11 @@
   /** 
     * \brief Axis2 Stream struct
     *
-    * Stream is the encapsulating struct for all stream related operations
+    * Stream is the encapsulating struct for all stream related ops
     */
     typedef struct axis2_stream
     {
-        /** Stream related operations */
+        /** Stream related ops */
         struct axis2_stream_ops *ops;
 		int axis2_eof;
     } axis2_stream_t;

Modified: webservices/axis2/trunk/c/include/axis2_svc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_ctx.h Mon Dec 12 22:23:36 2005
@@ -25,7 +25,7 @@
 
 #include <axis2_defines.h>
 #include <axis2_env.h>
-#include <axis2_operation_ctx.h>
+#include <axis2_op_ctx.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -42,8 +42,8 @@
 
     
 /** 
- * @brief Message Context operations struct
- * Encapsulator struct for operations of axis2_svc_ctx
+ * @brief Message Context ops struct
+ * Encapsulator struct for ops of axis2_svc_ctx
  */  
 struct axis2_svc_ctx_ops
 {
@@ -68,7 +68,7 @@
                                                 axis2_env_t **env);
     struct axis2_conf_ctx* (AXIS2_CALL *get_conf_ctx)(struct axis2_svc_ctx *svc_ctx, 
                                                 axis2_env_t **env);
-    axis2_operation_ctx_t* (AXIS2_CALL *create_operation_ctx)(struct axis2_svc_ctx *svc_ctx, 
+    axis2_op_ctx_t* (AXIS2_CALL *create_op_ctx)(struct axis2_svc_ctx *svc_ctx, 
                                                 axis2_env_t **env, axis2_qname_t *qname);
 };
 
@@ -94,7 +94,7 @@
 #define AXIS2_SVC_CTX_GET_SVC_ID(svc_ctx, env) ((svc_ctx)->ops->get_svc_id(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_SVC(svc_ctx, env) ((svc_ctx)->ops->get_svc(svc_ctx, env))
 #define AXIS2_SVC_CTX_GET_CONF_CTX(svc_ctx, env) ((svc_ctx)->ops->get_conf_ctx(svc_ctx, env))
-#define AXIS2_SVC_CTX_CREATE_OPERATION_CTX(svc_ctx, env, qname) ((svc_ctx)->ops->create_operation_ctx(svc_ctx, env, qname))
+#define AXIS2_SVC_CTX_CREATE_OPERATION_CTX(svc_ctx, env, qname) ((svc_ctx)->ops->create_op_ctx(svc_ctx, env, qname))
     
 /************************** End of function macros ****************************/    
 

Modified: webservices/axis2/trunk/c/include/axis2_svc_grp.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_grp.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_grp.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_grp.h Mon Dec 12 22:23:36 2005
@@ -41,8 +41,8 @@
 typedef struct axis2_svc_grp axis2_svc_grp_t;
     
 /** 
- * @brief Service group operations struct
- * Encapsulator struct for operations of axis2_svc_grp
+ * @brief Service group ops struct
+ * Encapsulator struct for ops of axis2_svc_grp
  */   
 struct axis2_svc_grp_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_grp_ctx.h Mon Dec 12 22:23:36 2005
@@ -42,8 +42,8 @@
 
     
 /** 
- * @brief Message Context operations struct
- * Encapsulator struct for operations of axis2_svc_grp_ctx
+ * @brief Message Context ops struct
+ * Encapsulator struct for ops of axis2_svc_grp_ctx
  */  
 struct axis2_svc_grp_ctx_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_svc_name.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_name.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc_name.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc_name.h Mon Dec 12 22:23:36 2005
@@ -42,7 +42,7 @@
  */
 
 /**
- *   \brief Dispatcher operations struct
+ *   \brief Dispatcher ops struct
  */
  AXIS2_DECLARE_DATA typedef struct axis2_svc_name_ops
     { 
@@ -83,7 +83,7 @@
     */
     typedef struct axis2_svc_name
     {
-        /** Dispatcher related operations */
+        /** Dispatcher related ops */
         axis2_svc_name_ops_t *ops;
     } axis2_svc_name_t;
 

Modified: webservices/axis2/trunk/c/include/axis2_transport_in_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_in_desc.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_in_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_in_desc.h Mon Dec 12 22:23:36 2005
@@ -51,8 +51,8 @@
  */
 
 /** 
- * @brief Description Transport In operations struct
- * Encapsulator struct for operations of axis2_transport_in_desc
+ * @brief Description Transport In ops struct
+ * Encapsulator struct for ops of axis2_transport_in_desc
  */
 AXIS2_DECLARE_DATA struct axis2_transport_in_desc_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_transport_out_desc.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_transport_out_desc.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_transport_out_desc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_transport_out_desc.h Mon Dec 12 22:23:36 2005
@@ -51,8 +51,8 @@
  */
 
 /** 
- * @brief Description Transport Out operations struct
- * Encapsulator struct for operations of axis2_transport_out_desc
+ * @brief Description Transport Out ops struct
+ * Encapsulator struct for ops of axis2_transport_out_desc
  */
 AXIS2_DECLARE_DATA struct axis2_transport_out_desc_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding.h Mon Dec 12 22:23:36 2005
@@ -28,7 +28,7 @@
 #include <axis2_env.h>
 #include <axis2_allocator.h>
 #include <axis2_hash.h>
-#include <axis2_wsdl_binding_operation.h>
+#include <axis2_wsdl_binding_op.h>
 #include <axis2_wsdl_binding_fault.h>
 #include <axis2_qname.h>
 #include <axis2_wsdl_interface.h>
@@ -39,7 +39,7 @@
 #endif
 
 struct axis2_wsdl_interface;
-struct axis2_wsdl_binding_operation;
+struct axis2_wsdl_binding_op;
 struct axis2_wsdl_binding_fault;
 struct axis2_wsdl_extensible_component;    
 typedef struct axis2_wsdl_binding axis2_wsdl_binding_t;
@@ -51,8 +51,8 @@
  */
 
 /** 
- * @brief Wsdl Binding operations struct
- * Encapsulator struct for operations of axis2_wsdl_binding
+ * @brief Wsdl Binding ops struct
+ * Encapsulator struct for ops of axis2_wsdl_binding
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_binding_ops
 {
@@ -135,7 +135,7 @@
      * @return Hashmap
      */
     axis2_hash_t * (AXIS2_CALL *
-    get_binding_operations) (axis2_wsdl_binding_t *binding,
+    get_binding_ops) (axis2_wsdl_binding_t *binding,
                                                 axis2_env_t **env);
     
     /**
@@ -144,9 +144,9 @@
      * @param bindingOperations
      */
     axis2_status_t (AXIS2_CALL *
-    set_binding_operations) (axis2_wsdl_binding_t *binding,
+    set_binding_ops) (axis2_wsdl_binding_t *binding,
                                                 axis2_env_t **env,
-                                                axis2_hash_t *binding_operations);
+                                                axis2_hash_t *binding_ops);
     
     /**
      * Method addBindingOperation
@@ -154,10 +154,10 @@
      * @param bindingOperation
      */
     axis2_status_t (AXIS2_CALL *
-    add_binding_operation) (
+    add_binding_op) (
                             axis2_wsdl_binding_t *binding,
                             axis2_env_t **env,
-                            struct axis2_wsdl_binding_operation *binding_operation);
+                            struct axis2_wsdl_binding_op *binding_op);
     
     /**
      * Method getBindingOperation
@@ -165,8 +165,8 @@
      * @param qName
      * @return WSDLBindingOperation
      */
-    struct axis2_wsdl_binding_operation *(AXIS2_CALL *
-    get_binding_operation) (axis2_wsdl_binding_t *binding,
+    struct axis2_wsdl_binding_op *(AXIS2_CALL *
+    get_binding_op) (axis2_wsdl_binding_t *binding,
                                                 axis2_env_t **env,
                                                 axis2_qname_t *qName);
     
@@ -235,18 +235,18 @@
 		((wsdl_binding->ops)->set_binding_faults (wsdl_binding, env, faults))
 
 #define AXIS2_WSDL_BINDING_GET_BINDING_OPERATIONS(wsdl_binding, env) \
-		((wsdl_binding->ops)->get_binding_operations (wsdl_binding, env))
+		((wsdl_binding->ops)->get_binding_ops (wsdl_binding, env))
 
-#define AXIS2_WSDL_BINDING_SET_BINDING_OPERATIONS(wsdl_binding, env, operations) \
-		((wsdl_binding->ops)->set_binding_operations (wsdl_binding, env, operations)) 
+#define AXIS2_WSDL_BINDING_SET_BINDING_OPERATIONS(wsdl_binding, env, ops) \
+		((wsdl_binding->ops)->set_binding_ops (wsdl_binding, env, ops)) 
         
-#define AXIS2_WSDL_BINDING_ADD_BINDING_OPERATION(wsdl_binding, env, operation) \
-		((wsdl_binding->ops)->add_binding_operation (wsdl_binding, env, operation))
+#define AXIS2_WSDL_BINDING_ADD_BINDING_OPERATION(wsdl_binding, env, op) \
+		((wsdl_binding->ops)->add_binding_op (wsdl_binding, env, op))
 
 #define AXIS2_WSDL_BINDING_GET_BINDING_OPERATION(wsdl_binding, env) \
-		((wsdl_binding->ops)->get_binding_operation (wsdl_binding, env)) 
+		((wsdl_binding->ops)->get_binding_op (wsdl_binding, env)) 
 
-#define AXIS2_WSDL_BINDING_ADD_BINDING_FAULT(wsdl_binding, env, operation) \
+#define AXIS2_WSDL_BINDING_ADD_BINDING_FAULT(wsdl_binding, env, op) \
 		((wsdl_binding->ops)->add_binding_fault (wsdl_binding, env, fault))
 
 #define AXIS2_WSDL_BINDING_GET_BINDING_FAULT(wsdl_binding, env) \

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding_fault.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding_fault.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding_fault.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding_fault.h Mon Dec 12 22:23:36 2005
@@ -45,8 +45,8 @@
  */
 
 /** 
- * @brief Wsdl Binding Fault operations struct
- * Encapsulator struct for operations of axis2_binding_fault
+ * @brief Wsdl Binding Fault ops struct
+ * Encapsulator struct for ops of axis2_binding_fault
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_binding_fault_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding_msg_ref.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding_msg_ref.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding_msg_ref.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding_msg_ref.h Mon Dec 12 22:23:36 2005
@@ -45,8 +45,8 @@
  */
 
 /** 
- * @brief Wsdl Binding Message Reference operations struct
- * Encapsulator struct for operations of axis2_wsdl_binding_msg_ref
+ * @brief Wsdl Binding Message Reference ops struct
+ * Encapsulator struct for ops of axis2_wsdl_binding_msg_ref
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_binding_msg_ref_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_component.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_component.h Mon Dec 12 22:23:36 2005
@@ -37,8 +37,8 @@
   */
 
 /** 
- * @brief Wsdl Component operations struct
- * Encapsulator struct for operations of axis2_wsdl_component
+ * @brief Wsdl Component ops struct
+ * Encapsulator struct for ops of axis2_wsdl_component
  */
 struct axis2_wsdl_component_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_endpoint.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_endpoint.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_endpoint.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_endpoint.h Mon Dec 12 22:23:36 2005
@@ -47,8 +47,8 @@
  */
 
 /** 
- * @brief Wsdl End point operations struct
- * Encapsulator struct for operations of axis2_wsdl_endpoint
+ * @brief Wsdl End point ops struct
+ * Encapsulator struct for ops of axis2_wsdl_endpoint
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_endpoint_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_extensible_component.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_extensible_component.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_extensible_component.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_extensible_component.h Mon Dec 12 22:23:36 2005
@@ -49,8 +49,8 @@
  */
 
 /** 
- * @brief Wsdl Extensible Component operations struct
- * Encapsulator struct for operations of axis2_wsdl_extensible_component
+ * @brief Wsdl Extensible Component ops struct
+ * Encapsulator struct for ops of axis2_wsdl_extensible_component
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_extensible_component_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_extensible_element.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_extensible_element.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_extensible_element.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_extensible_element.h Mon Dec 12 22:23:36 2005
@@ -43,8 +43,8 @@
  */
 
 /** 
- * @brief Wsdl Extensible Element operations struct
- * Encapsulator struct for operations of axis2_wsdl_extensible_element
+ * @brief Wsdl Extensible Element ops struct
+ * Encapsulator struct for ops of axis2_wsdl_extensible_element
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_extensible_element_ops
 {

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_fault_ref.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_fault_ref.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_fault_ref.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_fault_ref.h Mon Dec 12 22:23:36 2005
@@ -45,8 +45,8 @@
  */
 
 /** 
- * @brief Wsdl Binding Message Reference operations struct
- * Encapsulator struct for operations of axis2_wsdl_fault_ref
+ * @brief Wsdl Binding Message Reference ops struct
+ * Encapsulator struct for ops of axis2_wsdl_fault_ref
  */
 AXIS2_DECLARE_DATA struct axis2_wsdl_fault_ref_ops
 {
--- webservices/axis2/trunk/c/include/axis2_operation_ctx.h (original)
+++ webservices/axis2/trunk/c/include/axis2_operation_ctx.h Mon Dec 12 22:23:36 2005
@@ -19,7 +19,7 @@
 
 
 /**
-  * @file axis2_operation_ctx.h
+  * @file axis2_op_ctx.h
   * @brief axis2 Message Context interface
   */
 
@@ -27,7 +27,7 @@
 #include <axis2_hash.h>
 #include <axis2_env.h>
 #include <axis2_msg_ctx.h>
-#include <axis2_operation.h>
+#include <axis2_op.h>
 
 #ifdef __cplusplus
 extern "C"
@@ -35,15 +35,15 @@
 #endif
 
 /** 
  * @defgroup axis2_operation_ctx Operation Context 
  * An operation context represents a running "instance" of an operation, which is
  * represented by an axis2_operation struct. This concept is needed to allow
  * messages to be grouped into operations as in WSDL 2.0-speak operations are
  * essentially arbitrary message exchange patterns. So as messages are being
- * exchanged the operation context remembers the state of where in the message
+ * exchanged the op context remembers the state of where in the message
  * exchange pattern it is in.
  * <p/>
- * The base implementation of operation context
+ * The base implementation of op context
  * supports MEPs which have one input message and/or one output message. That
  * is, it supports the all the MEPs that are in the WSDL 2.0 specification. In
  * order to support another MEP one must extend this struct.
@@ -51,38 +51,38 @@
  * @{
  */
     
-typedef struct axis2_operation_ctx_ops axis2_operation_ctx_ops_t;
-typedef struct axis2_operation_ctx axis2_operation_ctx_t; 
+typedef struct axis2_op_ctx_ops axis2_op_ctx_ops_t;
+typedef struct axis2_op_ctx axis2_op_ctx_t; 
 struct axis2_svc_ctx;
     
 /** 
  * @brief Message Context operations struct
  * Encapsulator struct for operations of axis2_operation_ctx
  */  
-struct axis2_operation_ctx_ops
+struct axis2_op_ctx_ops
 {
-    axis2_ctx_t* (AXIS2_CALL *get_base)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_ctx_t* (AXIS2_CALL *get_base)(struct axis2_op_ctx *op_ctx, 
                                                 axis2_env_t **env);
     
-    axis2_status_t (AXIS2_CALL *free)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_status_t (AXIS2_CALL *free)(struct axis2_op_ctx *op_ctx, 
                                        axis2_env_t **env);
     
     /**
      * The method is used to do the intialization of the axis2_operation_ctx
      */
-    axis2_status_t (AXIS2_CALL *init)(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config);
+    axis2_status_t (AXIS2_CALL *init)(struct axis2_op_ctx *op_ctx, axis2_env_t **env, struct axis2_engine_config *engine_config);
     
     /**
-     * @return Returns the operation.
+     * @return Returns the op.
      */
-    axis2_operation_t* (AXIS2_CALL *get_operation)(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env);
+    axis2_op_t* (AXIS2_CALL *get_op)(struct axis2_op_ctx *op_ctx, axis2_env_t **env);
     
     /**
      * Return the struct axis2_svc_ctx * in which this operation_ctx lives.
      *
      * @return parent struct axis2_svc_ctx *
      */
-    struct axis2_svc_ctx* (AXIS2_CALL *get_parent)(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env);
+    struct axis2_svc_ctx* (AXIS2_CALL *get_parent)(struct axis2_op_ctx *op_ctx, axis2_env_t **env);
     
     /**
      * When a new message is added to the <code>MEPContext</code> the logic
@@ -92,14 +92,14 @@
      *
      * @param msgContext
      */
-    axis2_status_t (AXIS2_CALL *add_msg_ctx)(struct axis2_operation_ctx *operation_ctx, axis2_env_t **env, axis2_msg_ctx_t *msg_ctx);
+    axis2_status_t (AXIS2_CALL *add_msg_ctx)(struct axis2_op_ctx *op_ctx, axis2_env_t **env, axis2_msg_ctx_t *msg_ctx);
     
     /**
      * @param message_id
      * @return
      * @throws AxisFault
      */
-    axis2_msg_ctx_t* (AXIS2_CALL *get_msg_ctx)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_msg_ctx_t* (AXIS2_CALL *get_msg_ctx)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env, axis2_char_t *message_id);
     
     /**
@@ -107,31 +107,31 @@
      * are associated with the MEP has arrived and MEP is complete.
      *
      */
-    axis2_bool_t (AXIS2_CALL *get_is_complete)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_bool_t (AXIS2_CALL *get_is_complete)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env);
     
-    axis2_status_t (AXIS2_CALL *set_complete)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_status_t (AXIS2_CALL *set_complete)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env, 
         axis2_bool_t is_complete);
     
     /**
      * Removes the pointers to this <code>operation_ctx</code> in the
      * <code>axis2_conf_ctx</code>'s operation_ctxaxis2_hash_t *so that this
      * <code>operation_ctx</code> will eventually get garbage collected
      * along with the <code>axis2_msg_ctx_t *</code>'s it contains. Note that if
      * the caller wants to make sure its safe to clean up this operation_ctx
      * he should call is_complete() first. However, in cases like IN_OPTIONAL_OUT
      * and OUT_OPTIONAL_IN, it is possibe this will get called without the MEP
      * being complete due to the optional nature of the MEP.
      */
-    axis2_status_t (AXIS2_CALL *cleanup)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_status_t (AXIS2_CALL *cleanup)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env);
     
-    axis2_status_t (AXIS2_CALL *set_parent)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_status_t (AXIS2_CALL *set_parent)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env, 
         struct axis2_svc_ctx *svc_ctx);
     
-    axis2_hash_t* (AXIS2_CALL *get_msg_ctx_map)(struct axis2_operation_ctx *operation_ctx, 
+    axis2_hash_t* (AXIS2_CALL *get_msg_ctx_map)(struct axis2_op_ctx *op_ctx, 
         axis2_env_t **env);
 };
 
@@ -139,28 +139,28 @@
  * @brief Message Context struct
   *	Axis2 Message Context
  */
-struct axis2_operation_ctx
+struct axis2_op_ctx
 {
-    axis2_operation_ctx_ops_t *ops;    
+    axis2_op_ctx_ops_t *ops;    
 };
 
-axis2_operation_ctx_t* AXIS2_CALL axis2_operation_ctx_create(axis2_env_t **env, 
-    axis2_operation_t *operation,
+axis2_op_ctx_t* AXIS2_CALL axis2_op_ctx_create(axis2_env_t **env, 
+    axis2_op_t *op,
     struct axis2_svc_ctx * svc_ctx);
     
 /************************** Start of function macros **************************/
-#define OPERATION_CTX_GET_BASE(operation_ctx, env) ((operation_ctx)->ops->get_base(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_FREE(operation_ctx, env) ((operation_ctx)->ops->free(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_INIT(operation_ctx, env, engine_config) ((operation_ctx)->ops->init(operation_ctx, env, engine_config))
-#define AXIS2_OPERATION_CTX_GET_OPERATION(operation_ctx, env) ((operation_ctx)->ops->get_operation(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_GET_PARENT(operation_ctx, env) ((operation_ctx)->ops->get_parent(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_ADD_MSG_CTX(operation_ctx, env, msg_ctx) ((operation_ctx)->ops->add_msg_ctx(operation_ctx, env, msg_ctx))
-#define AXIS2_OPERATION_CTX_GET_MSG_CTX(operation_ctx, env, message_id) ((operation_ctx)->ops->get_msg_ctx(operation_ctx, env, message_id))
-#define AXIS2_OPERATION_CTX_GET_IS_COMPLETE(operation_ctx, env) ((operation_ctx)->ops->get_is_complete(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_SET_IS_COMPLETE(operation_ctx, env, is_complete) ((operation_ctx)->ops->set_is_complete(operation_ctx, env, is_complete))
-#define AXIS2_OPERATION_CTX_CLEANUP(operation_ctx, env) ((operation_ctx)->ops->cleanup(operation_ctx, env))
-#define AXIS2_OPERATION_CTX_SET_PARENT(operation_ctx, env, svc_ctx) ((operation_ctx)->ops->set_parent(operation_ctx, env, svc_ctx))
-#define AXIS2_OPERATION_CTX_GET_MSG_CTX_MAP(operation_ctx, env) ((operation_ctx)->ops->get_msg_ctx_map(operation_ctx, env))    
+#define OPERATION_CTX_GET_BASE(op_ctx, env) ((op_ctx)->ops->get_base(op_ctx, env))
+#define AXIS2_OPERATION_CTX_FREE(op_ctx, env) ((op_ctx)->ops->free(op_ctx, env))
+#define AXIS2_OPERATION_CTX_INIT(op_ctx, env, engine_config) ((op_ctx)->ops->init(op_ctx, env, engine_config))
+#define AXIS2_OPERATION_CTX_GET_OPERATION(op_ctx, env) ((op_ctx)->ops->get_op(op_ctx, env))
+#define AXIS2_OPERATION_CTX_GET_PARENT(op_ctx, env) ((op_ctx)->ops->get_parent(op_ctx, env))
+#define AXIS2_OPERATION_CTX_ADD_MSG_CTX(op_ctx, env, msg_ctx) ((op_ctx)->ops->add_msg_ctx(op_ctx, env, msg_ctx))
+#define AXIS2_OPERATION_CTX_GET_MSG_CTX(op_ctx, env, message_id) ((op_ctx)->ops->get_msg_ctx(op_ctx, env, message_id))
+#define AXIS2_OPERATION_CTX_GET_IS_COMPLETE(op_ctx, env) ((op_ctx)->ops->get_is_complete(op_ctx, env))
+#define AXIS2_OPERATION_CTX_SET_IS_COMPLETE(op_ctx, env, is_complete) ((op_ctx)->ops->set_is_complete(op_ctx, env, is_complete))
+#define AXIS2_OPERATION_CTX_CLEANUP(op_ctx, env) ((op_ctx)->ops->cleanup(op_ctx, env))
+#define AXIS2_OPERATION_CTX_SET_PARENT(op_ctx, env, svc_ctx) ((op_ctx)->ops->set_parent(op_ctx, env, svc_ctx))
+#define AXIS2_OPERATION_CTX_GET_MSG_CTX_MAP(op_ctx, env) ((op_ctx)->ops->get_msg_ctx_map(op_ctx, env))    
 
 /************************** End of function macros ****************************/    
 
@@ -35,15 +35,15 @@
 
 /** 
- * @defgroup axis2_operation_ctx Operation Context 
- * An operation context represents a running "instance" of an operation, which is
- * represented by an axis2_operation struct. This concept is needed to allow
- * messages to be grouped into operations as in WSDL 2.0-speak operations are
+ * @defgroup axis2_op_ctx Operation Context 
+ * An op context represents a running "instance" of an op, which is
+ * represented by an axis2_op struct. This concept is needed to allow
+ * messages to be grouped into ops as in WSDL 2.0-speak ops are
  * essentially arbitrary message exchange patterns. So as messages are being
@@ -51,38 +51,38 @@
     
 /** 
- * @brief Message Context operations struct
- * Encapsulator struct for operations of axis2_operation_ctx
+ * @brief Message Context ops struct
+ * Encapsulator struct for ops of axis2_op_ctx
  */  
@@ -51,38 +51,38 @@
     
     /**
-     * The method is used to do the intialization of the axis2_operation_ctx
+     * The method is used to do the intialization of the axis2_op_ctx
      */
@@ -51,38 +51,38 @@
     
     /**
-     * Return the struct axis2_svc_ctx * in which this operation_ctx lives.
+     * Return the struct axis2_svc_ctx * in which this op_ctx lives.
      *
      * @return parent struct axis2_svc_ctx *
@@ -107,31 +107,31 @@
     
     /**
-     * Removes the pointers to this <code>operation_ctx</code> in the
-     * <code>axis2_conf_ctx</code>'s operation_ctxaxis2_hash_t *so that this
-     * <code>operation_ctx</code> will eventually get garbage collected
+     * Removes the pointers to this <code>op_ctx</code> in the
+     * <code>axis2_conf_ctx</code>'s op_ctxaxis2_hash_t *so that this
+     * <code>op_ctx</code> will eventually get garbage collected
      * along with the <code>axis2_msg_ctx_t *</code>'s it contains. Note that if
@@ -107,31 +107,31 @@
      * along with the <code>axis2_msg_ctx_t *</code>'s it contains. Note that if
-     * the caller wants to make sure its safe to clean up this operation_ctx
+     * the caller wants to make sure its safe to clean up this op_ctx
      * he should call is_complete() first. However, in cases like IN_OPTIONAL_OUT
      * and OUT_OPTIONAL_IN, it is possibe this will get called without the MEP

Modified: webservices/axis2/trunk/c/include/axis2_param.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_param.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_svc.h (original)
+++ webservices/axis2/trunk/c/include/axis2_svc.h Mon Dec 12 22:23:36 2005
@@ -26,7 +26,7 @@
 #include <axis2_param_container.h>
 #include <axis2_flow_container.h>
 #include <axis2_wsdl_svc.h>
-#include <axis2_operation.h>
+#include <axis2_op.h>
 #include <axis2_svc_grp.h>
 #include <axis2_qname.h>
 #include <axis2_error.h>
@@ -35,7 +35,7 @@
 #include <axis2_phase_resolver.h>
 #include <axis2_module_desc.h>
 #include <axis2_engine_config.h>
-#include <axis2_wsdl_soap_operation.h>
+#include <axis2_wsdl_soap_op.h>
 #include <axis2_string.h>
 #include <axis2_wsdl_endpoint.h>
 
@@ -51,20 +51,20 @@
 
 struct axis2_wsdl_endpoint;
 struct axis2_svc_grp;
-struct axis2_operation;
+struct axis2_op;
 struct axis2_flow_container;
 struct axis2_param_container;
 struct axis2_wsdl_svc;
 struct axis2_wsdl_interface; 
 struct axis2_module_desc; 
 struct axis2_engine_config;
-struct axis2_wsdl_soap_operation;    
+struct axis2_wsdl_soap_op;    
 typedef struct axis2_svc_ops axis2_svc_ops_t;   
 typedef struct axis2_svc axis2_svc_t;
     
 /** 
- * @brief Service operations struct
- * Encapsulator struct for operations of axis2_svc
+ * @brief Service ops struct
+ * Encapsulator struct for ops of axis2_svc
  */    
 struct axis2_svc_ops
 {
@@ -73,22 +73,22 @@
             axis2_env_t **env);
 
 	axis2_status_t (AXIS2_CALL *
-    add_operation) (axis2_svc_t *svc, 
+    add_op) (axis2_svc_t *svc, 
                     axis2_env_t **env,
-                    struct axis2_operation *operation);
+                    struct axis2_op *op);
 
-	struct axis2_operation *(AXIS2_CALL *
-    get_operation_with_qname) (axis2_svc_t *svc, 
+	struct axis2_op *(AXIS2_CALL *
+    get_op_with_qname) (axis2_svc_t *svc, 
                                   axis2_env_t **env,
-                                  axis2_qname_t *operation_qname);
+                                  axis2_qname_t *op_qname);
 
-	struct axis2_operation *(AXIS2_CALL *
-    get_operation_with_name) (axis2_svc_t *svc, 
+	struct axis2_op *(AXIS2_CALL *
+    get_op_with_name) (axis2_svc_t *svc, 
                                 axis2_env_t **env,
-                                const axis2_char_t * operation_name);
+                                const axis2_char_t * op_name);
 
 	axis2_hash_t *(AXIS2_CALL *
-    get_operations) (axis2_svc_t *svc, 
+    get_ops) (axis2_svc_t *svc, 
                      axis2_env_t **env);
 
 	axis2_status_t (AXIS2_CALL *
@@ -156,7 +156,7 @@
      * @param module
      */
     axis2_status_t (AXIS2_CALL *
-    add_module_operations) (axis2_svc_t *svc,
+    add_module_ops) (axis2_svc_t *svc,
                                 axis2_env_t **env,
                                 struct axis2_module_desc * module_desc,
                                 struct axis2_engine_config * axis2_config); 
@@ -177,13 +177,13 @@
     
     /**
      * To get the WSDL opeartion element in servic einterface
-     * @param operationName  <code>QName</cde>
+     * @param opName  <code>QName</cde>
      * @return  WSDLOperation <code>WSDLOperation</code>
      */
     void * (AXIS2_CALL *
-    get_wsdl_operation) (axis2_svc_t *svc,
+    get_wsdl_op) (axis2_svc_t *svc,
                                     axis2_env_t **env,
-                                    axis2_qname_t *operation_name);
+                                    axis2_qname_t *op_name);
     
        /**
      * Method setContextPath
@@ -290,7 +290,7 @@
                         struct axis2_flow *fault_flow);
     
     /**
-     * This method will return the operation given particular SOAP Action.
+     * This method will return the op given particular SOAP Action.
      * This method should only be called if there is only one Endpoint is defined
      * for this Service. If more than one Endpoint exists one of them will be picked.
      * If more than one Operation is found with the given
@@ -298,16 +298,16 @@
      * the given SOAP Action; null will be returned.
      *
      * @param soapAction SOAP Action defined for the particular Operation
      * @return A struct axis2_operation * if a unque Operation can be found with the given SOAP Action
      *         otherwise will return null.
      */
-    struct axis2_operation * (AXIS2_CALL *
-    get_operation_by_soap_action) (axis2_svc_t *svc,
+    struct axis2_op * (AXIS2_CALL *
+    get_op_by_soap_action) (axis2_svc_t *svc,
                                     axis2_env_t **env,
                                     axis2_char_t *soap_action);
     
     /**
-     * This method will return the operation given the particular endpoing and the
+     * This method will return the op given the particular endpoing and the
      * particular SOAP Action. If more than one Operation is found with the given
      * SOAP Action; null will be ruturned. If no particular Operation is found with
      * the given SOAP Action; null will be returned
@@ -315,11 +315,11 @@
      * @param endpoint   Particular Enpoint in which the bining is defined with the particular SOAP
      *                   Action.
      * @param soapAction SOAP Action defined for the particular Operation
      * @return A struct axis2_operation * if a unque Operation can be found with the given SOAP Action
      *         otherwise will return null.
      */
-    struct axis2_operation * (AXIS2_CALL *
-    get_operation_by_soap_action_and_endpoint) (axis2_svc_t *svc,
+    struct axis2_op * (AXIS2_CALL *
+    get_op_by_soap_action_and_endpoint) (axis2_svc_t *svc,
                                     axis2_env_t **env,
                                     axis2_char_t *soap_action,
                                     axis2_qname_t * endpoint);       
@@ -393,7 +393,7 @@
     add_mapping) (axis2_svc_t *svc,
                 axis2_env_t **env,
                 axis2_char_t * mapping_key , 
-                struct axis2_operation * axis2_operation);
+                struct axis2_op * axis2_op);
  
     axis2_status_t (AXIS2_CALL *
     add_module_ref) (axis2_svc_t *svc,
@@ -447,16 +447,16 @@
 
 #define AXIS2_SVC_FREE(svc, env) (svc->ops->free (svc, env))
 
-#define AXIS2_SVC_ADD_OPERATION(svc, env, operation) \
-		(svc->ops->add_operation (svc, env, operation))
+#define AXIS2_SVC_ADD_OPERATION(svc, env, op) \
+		(svc->ops->add_op (svc, env, op))
 
-#define AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, operation_qname) \
-		(svc->ops->get_operation_with_qname (svc, env, operation_qname))
+#define AXIS2_SVC_GET_OPERATION_WITH_QNAME(svc, env, op_qname) \
+		(svc->ops->get_op_with_qname (svc, env, op_qname))
 
-#define AXIS2_SVC_GET_OPERATION_WITH_NAME(svc, env, operation_name) \
-		(svc->ops->get_operation_with_name (svc, env, operation_name))
+#define AXIS2_SVC_GET_OPERATION_WITH_NAME(svc, env, op_name) \
+		(svc->ops->get_op_with_name (svc, env, op_name))
 
-#define AXIS2_SVC_GET_OPERATIONS(svc, env) (svc->ops->get_operations (svc, env))
+#define AXIS2_SVC_GET_OPERATIONS(svc, env) (svc->ops->get_ops (svc, env))
 
 #define AXIS2_SVC_SET_PARENT(svc, env , svc_grp) (svc->ops->set_parent \
         (svc, env, svc_grp))
@@ -486,7 +486,7 @@
         (svc->ops->engage_module(svc, env, moduleref, axis2_config))
 
 #define AXIS2_SVC_ADD_MODULE_OPERATIONS(svc, env, module_desc, axis2_config) \
-        (svc->ops->add_module_operations(svc, env, module_desc, axis2_config))
+        (svc->ops->add_module_ops(svc, env, module_desc, axis2_config))
 
 #define AXIS2_SVC_ADD_TO_ENGAGED_MODULE_LIST(svc, env, module_name) \
         (svc->ops->add_to_engaged_module_list(svc, env, module_name))
@@ -494,8 +494,8 @@
 #define AXIS2_SVC_GET_ENGAGED_MODULES(svc, env) \
         (svc->ops->get_engaged_modules(svc, env))
 
-#define AXIS2_SVC_GET_WSDL_OPERATION(svc, env, operation_name) \
-        (svc->ops->get_wsdl_operation(svc, env, operation_name))
+#define AXIS2_SVC_GET_WSDL_OPERATION(svc, env, op_name) \
+        (svc->ops->get_wsdl_op(svc, env, op_name))
 
 #define AXIS2_SVC_SET_CONTEXT_PATH(svc, env, context_path) \
         (svc->ops->set_context_path(svc, env, context_path))
@@ -534,10 +534,10 @@
         (svc->ops->set_fault_outflow(svc, env, fault_outflow))
 
 #define AXIS2_SVC_GET_OPERATION_BY_SOAP_ACTION(svc, env, soap_action) \
-        (svc->ops->get_operation_by_soap_action(svc, env, soap_action))
+        (svc->ops->get_op_by_soap_action(svc, env, soap_action))
 
 #define AXIS2_SVC_GET_OPERATION_BY_SOAP_ACTION_AND_ENDPOINT(svc, env, soap_action, endpoint) \
-        (svc->ops->get_operation_by_soap_action_and_endpoint(svc, env, soap_action, endpoint))
+        (svc->ops->get_op_by_soap_action_and_endpoint(svc, env, soap_action, endpoint))
 
 #define AXIS2_SVC_GET_AXIS2_SVC_NAME(svc, env) \
         (svc->ops->get_axis2_svc_name(svc, env))
@@ -298,16 +298,16 @@
      *
      * @param soapAction SOAP Action defined for the particular Operation
-     * @return A struct axis2_operation * if a unque Operation can be found with the given SOAP Action
+     * @return A struct axis2_op * if a unque Operation can be found with the given SOAP Action
      *         otherwise will return null.
      */
@@ -315,11 +315,11 @@
      *                   Action.
      * @param soapAction SOAP Action defined for the particular Operation
-     * @return A struct axis2_operation * if a unque Operation can be found with the given SOAP Action
+     * @return A struct axis2_op * if a unque Operation can be found with the given SOAP Action
      *         otherwise will return null.
      */

Modified: webservices/axis2/trunk/c/include/axis2_svc_ctx.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_svc_ctx.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================
--- webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h (original)
+++ webservices/axis2/trunk/c/include/axis2_wsdl_binding_operation.h Mon Dec 12 22:23:36 2005
@@ -2,8 +2,8 @@
 #define AXIS2_WSDL_BINDING_OPERATION_H
 
 /**
- * @file axis2_wsdl_binding_operation.h
- * @brief axis2 wsdl binding_operation interface. 
+ * @file axis2_wsdl_binding_op.h
+ * @brief axis2 wsdl binding_op interface. 
  */
 #include <axis2.h>
 #include <axis2_error.h>
@@ -16,7 +16,7 @@
 #include <axis2_qname.h>
 #include <axis2_wsdl_extensible_component.h>
 #include <axis2_wsdl_binding_msg_ref.h>
-#include <axis2_wsdl_operation.h>
+#include <axis2_wsdl_op.h>
 #include <axis2_wsdl_binding_fault.h>
 
 #ifdef __cplusplus
@@ -27,25 +27,25 @@
 struct axis2_wsdl_binding_msg_ref;
 struct axis2_wsdl_binding_fault;
 struct axis2_wsdl_extensible_component;	
-typedef struct axis2_wsdl_binding_operation_ops axis2_wsdl_binding_operation_ops_t;
-typedef struct axis2_wsdl_binding_operation axis2_wsdl_binding_operation_t;
+typedef struct axis2_wsdl_binding_op_ops axis2_wsdl_binding_op_ops_t;
+typedef struct axis2_wsdl_binding_op axis2_wsdl_binding_op_t;
 	
 /** @defgroup axis2_wsdl_binding_operation Wsdl Binding Operation
   * @ingroup axis2_wsdl
   * @{
   */
 
 /** 
  * @brief Wsdl Binding Operation operations struct
  * Encapsulator struct for operations of axis2_wsdl_binding_operation
  */
-struct axis2_wsdl_binding_operation_ops
+struct axis2_wsdl_binding_op_ops
 {
 	/** Deallocate memory
      * @return status code
      */
     axis2_status_t (AXIS2_CALL *
-    free) (axis2_wsdl_binding_operation_t *wsdl_binding_operation, 
+    free) (axis2_wsdl_binding_op_t *wsdl_binding_op, 
                                         axis2_env_t **env);
     
     /**
@@ -54,7 +54,7 @@
      * @return message reference
      */
     struct axis2_wsdl_binding_msg_ref * (AXIS2_CALL *
-    get_input) (axis2_wsdl_binding_operation_t *binding_operation,
+    get_input) (axis2_wsdl_binding_op_t *binding_op,
                                             axis2_env_t **env);
     
     
@@ -64,28 +64,28 @@
      * @param input
      */
     axis2_status_t (AXIS2_CALL *
-    set_input) (axis2_wsdl_binding_operation_t *binding_operation,
+    set_input) (axis2_wsdl_binding_op_t *binding_op,
                                             axis2_env_t **env,
                                             struct axis2_wsdl_binding_msg_ref *input);
     
     /**
      * Method getOperation
      *
-     * @return operation
+     * @return op
      */
     void *(AXIS2_CALL *
-    get_operation) (axis2_wsdl_binding_operation_t *binding_operation,
+    get_op) (axis2_wsdl_binding_op_t *binding_op,
                                         axis2_env_t **env);
     
     /**
      * Method setOperation
      *
-     * @param operation
+     * @param op
      */
     axis2_status_t (AXIS2_CALL *
-    set_operation)(axis2_wsdl_binding_operation_t *binding_operation,
+    set_op)(axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
-                                                void *operation);
+                                                void *op);
     
     /**
      * Method getOutput
@@ -93,7 +93,7 @@
      * @return message reference
      */
     struct axis2_wsdl_binding_msg_ref * (AXIS2_CALL *
-    get_output)(axis2_wsdl_binding_operation_t *binding_operation,
+    get_output)(axis2_wsdl_binding_op_t *binding_op,
                                             axis2_env_t **env);
     
     /**
@@ -102,7 +102,7 @@
      * @param output
      */
     axis2_status_t (AXIS2_CALL *
-    set_output) (axis2_wsdl_binding_operation_t *binding_operation,
+    set_output) (axis2_wsdl_binding_op_t *binding_op,
                                             axis2_env_t **env,
                                             struct axis2_wsdl_binding_msg_ref *output);
     
@@ -112,7 +112,7 @@
      * @return QName
      */
     axis2_qname_t *(AXIS2_CALL *
-    get_qname) (axis2_wsdl_binding_operation_t *binding_operation,
+    get_qname) (axis2_wsdl_binding_op_t *binding_op,
                                         axis2_env_t **env);
     
     /**
@@ -121,7 +121,7 @@
      * @param name
      */
     axis2_status_t (AXIS2_CALL *
-    set_qname) (axis2_wsdl_binding_operation_t *binding_operation,
+    set_qname) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
                                                 axis2_qname_t *qname);
     
@@ -131,7 +131,7 @@
      * @param inFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_infault) (axis2_wsdl_binding_operation_t *binding_operation,
+    add_infault) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
                                                 struct axis2_wsdl_binding_fault *infault);
     
@@ -141,25 +141,25 @@
      * @param outFault
      */
     axis2_status_t (AXIS2_CALL *
-    add_outfault) (axis2_wsdl_binding_operation_t *binding_operation,
+    add_outfault) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
                                                 struct axis2_wsdl_binding_fault *outfault);
     
     axis2_linked_list_t * (AXIS2_CALL *
-    get_infaults) (axis2_wsdl_binding_operation_t *binding_operation,
+    get_infaults) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_infaults) (axis2_wsdl_binding_operation_t *binding_operation,
+    set_infaults) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
                                                 axis2_linked_list_t *infaults);
     
     axis2_linked_list_t * (AXIS2_CALL *
-    get_outfaults) (axis2_wsdl_binding_operation_t *binding_operation,
+    get_outfaults) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env);
     
     axis2_status_t (AXIS2_CALL *
-    set_outfaults) (axis2_wsdl_binding_operation_t *binding_operation,
+    set_outfaults) (axis2_wsdl_binding_op_t *binding_op,
                                                 axis2_env_t **env,
                                                 axis2_linked_list_t *outfaults);
 };
@@ -167,67 +167,67 @@
 /**
  * @brief Wsdl Binding Operation struct
  * Axis2 Wsdl Binding Operation
  * Binding Operation is used to hold wsdl_binding_operation properties
  */
-struct axis2_wsdl_binding_operation
+struct axis2_wsdl_binding_op
 {
-	axis2_wsdl_binding_operation_ops_t *ops;
+	axis2_wsdl_binding_op_ops_t *ops;
     struct axis2_wsdl_extensible_component *extensible_component;
 };
 
 /** create Wsdl Binding Operation struct
  * @return pointer to newly created wsdl wsdl_binding_operation
  */
-AXIS2_DECLARE(axis2_wsdl_binding_operation_t *) 
-axis2_wsdl_binding_operation_create (axis2_env_t **env);
+AXIS2_DECLARE(axis2_wsdl_binding_op_t *) 
+axis2_wsdl_binding_op_create (axis2_env_t **env);
 
 /**************************** Start of function macros ************************/
 
-#define AXIS2_WSDL_BINDING_OPERATION_FREE(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->free (wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_FREE(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->free (wsdl_binding_op, env))
 
-#define AXIS2_WSDL_BINDING_OPERATION_SET_INPUT(wsdl_binding_operation, env, \
+#define AXIS2_WSDL_BINDING_OPERATION_SET_INPUT(wsdl_binding_op, env, \
 		inut) \
-		((wsdl_binding_operation->ops)->set_input(wsdl_binding_operation , env, \
+		((wsdl_binding_op->ops)->set_input(wsdl_binding_op , env, \
             input)
 	
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OPERATION(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->get_operation(wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_GET_OPERATION(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->get_op(wsdl_binding_op, env))
 
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OPERATION(wsdl_binding_operation, env, \
-		key, operation) \
-		((wsdl_binding_operation->ops)->set_operation(wsdl_binding_operation, env,\
-            key, operation))
+#define AXIS2_WSDL_BINDING_OPERATION_SET_OPERATION(wsdl_binding_op, env, \
+		key, op) \
+		((wsdl_binding_op->ops)->set_op(wsdl_binding_op, env,\
+            key, op))
 		
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTPUT(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->get_output(wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTPUT(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->get_output(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTPUT(wsdl_binding_operation, env, output) \
-		((wsdl_binding_operation->ops)->set_output(wsdl_binding_operation, env, output))
+#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTPUT(wsdl_binding_op, env, output) \
+		((wsdl_binding_op->ops)->set_output(wsdl_binding_op, env, output))
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_QNAME(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->get_qname(wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_GET_QNAME(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->get_qname(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_QNAME(wsdl_binding_operation, env, qname) \
-		((wsdl_binding_operation->ops)->set_qname(wsdl_binding_operation, env, qname))
+#define AXIS2_WSDL_BINDING_OPERATION_SET_QNAME(wsdl_binding_op, env, qname) \
+		((wsdl_binding_op->ops)->set_qname(wsdl_binding_op, env, qname))
 
-#define AXIS2_WSDL_BINDING_OPERATION_ADD_INFAULT(wsdl_binding_operation, env, infault) \
-		((wsdl_binding_operation->ops)->add_infault(wsdl_binding_operation, env, infault))
+#define AXIS2_WSDL_BINDING_OPERATION_ADD_INFAULT(wsdl_binding_op, env, infault) \
+		((wsdl_binding_op->ops)->add_infault(wsdl_binding_op, env, infault))
         
-#define AXIS2_WSDL_BINDING_OPERATION_ADD_OUTFAULT(wsdl_binding_operation, env, outfault) \
-		((wsdl_binding_operation->ops)->add_outfault(wsdl_binding_operation, env, outfault))
+#define AXIS2_WSDL_BINDING_OPERATION_ADD_OUTFAULT(wsdl_binding_op, env, outfault) \
+		((wsdl_binding_op->ops)->add_outfault(wsdl_binding_op, env, outfault))
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_INFAULTS(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->get_infaults(wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_GET_INFAULTS(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->get_infaults(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_INFAULTS(wsdl_binding_operation, env, infaults) \
-		((wsdl_binding_operation->ops)->set_infaults(wsdl_binding_operation, env, infaults))        
+#define AXIS2_WSDL_BINDING_OPERATION_SET_INFAULTS(wsdl_binding_op, env, infaults) \
+		((wsdl_binding_op->ops)->set_infaults(wsdl_binding_op, env, infaults))        
 
-#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTFAULTS(wsdl_binding_operation, env) \
-		((wsdl_binding_operation->ops)->get_outfaults(wsdl_binding_operation, env))
+#define AXIS2_WSDL_BINDING_OPERATION_GET_OUTFAULTS(wsdl_binding_op, env) \
+		((wsdl_binding_op->ops)->get_outfaults(wsdl_binding_op, env))
         
-#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTFAULTS(wsdl_binding_operation, env, outfaults) \
-		((wsdl_binding_operation->ops)->set_outfaults(wsdl_binding_operation, env, outfaults))
+#define AXIS2_WSDL_BINDING_OPERATION_SET_OUTFAULTS(wsdl_binding_op, env, outfaults) \
+		((wsdl_binding_op->ops)->set_outfaults(wsdl_binding_op, env, outfaults))
      
 /**************************** End of function macros **************************/
 
@@ -27,25 +27,25 @@
 	
-/** @defgroup axis2_wsdl_binding_operation Wsdl Binding Operation
+/** @defgroup axis2_wsdl_binding_op Wsdl Binding Operation
   * @ingroup axis2_wsdl
   * @{
@@ -27,25 +27,25 @@
 
 /** 
- * @brief Wsdl Binding Operation operations struct
- * Encapsulator struct for operations of axis2_wsdl_binding_operation
+ * @brief Wsdl Binding Operation ops struct
+ * Encapsulator struct for ops of axis2_wsdl_binding_op
  */
@@ -167,67 +167,67 @@
  * @brief Wsdl Binding Operation struct
  * Axis2 Wsdl Binding Operation
- * Binding Operation is used to hold wsdl_binding_operation properties
+ * Binding Operation is used to hold wsdl_binding_op properties
  */
@@ -167,67 +167,67 @@
 
 /** create Wsdl Binding Operation struct
- * @return pointer to newly created wsdl wsdl_binding_operation
+ * @return pointer to newly created wsdl wsdl_binding_op
  */

Modified: webservices/axis2/trunk/c/include/axis2_wsdl_component.h
URL: http://svn.apache.org/viewcvs/webservices/axis2/trunk/c/include/axis2_wsdl_component.h?rev=356488&r1=356487&r2=356488&view=diff
==============================================================================